// Author: Frank Benoit
// This prints the sizes of some C struct how the GCC sees them
// Build with:
// gcc structs.c `pkg-config --cflags xtst cairo-xlib-xrender gtk+-2.0 gtk+-x11-2.0 pangox gdk-2.0 fontconfig gthread-2.0 cairo-xlib cairo pango gtk+-unix-print-2.0`   2>&1 | head -n 20

#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <glib.h>
#include <pango/pango.h>
#include <cairo.h>
#include <atk/atk.h>
#include <gconv.h>
#include <GL/glx.h>
#include <GL/gl.h>
#include <gtk/gtkprintunixdialog.h>
#include <gtk/gtkpagesetupunixdialog.h>
#include <X11/extensions/XInput.h>
#include <X11/extensions/Xrender.h>

typedef struct {
	const char* name;
	int size;
} TSizeValue;

const TSizeValue size_values[] = {
	{ "AtkValueIface", sizeof( AtkValueIface ) },
	{ "AtkMiscClass", sizeof( AtkMiscClass ) },
	{ "AtkMisc", sizeof( AtkMisc ) },
	{ "AtkTableIface", sizeof( AtkTableIface ) },
	{ "AtkStreamableContentIface", sizeof( AtkStreamableContentIface ) },
	{ "AtkStateSetClass", sizeof( AtkStateSetClass ) },
	{ "AtkSelectionIface", sizeof( AtkSelectionIface ) },
	{ "AtkRelationSetClass", sizeof( AtkRelationSetClass ) },
	{ "AtkRelationClass", sizeof( AtkRelationClass ) },
	{ "AtkRelation", sizeof( AtkRelation ) },
	{ "AtkRegistryClass", sizeof( AtkRegistryClass ) },
	{ "AtkRegistry", sizeof( AtkRegistry ) },
	{ "AtkNoOpObjectFactoryClass", sizeof( AtkNoOpObjectFactoryClass ) },
	{ "AtkNoOpObjectFactory", sizeof( AtkNoOpObjectFactory ) },
	{ "AtkObjectFactoryClass", sizeof( AtkObjectFactoryClass ) },
	{ "AtkObjectFactory", sizeof( AtkObjectFactory ) },
	{ "AtkNoOpObjectClass", sizeof( AtkNoOpObjectClass ) },
	{ "AtkNoOpObject", sizeof( AtkNoOpObject ) },
	{ "AtkImageIface", sizeof( AtkImageIface ) },
	{ "AtkHypertextIface", sizeof( AtkHypertextIface ) },
	{ "AtkHyperlinkImplIface", sizeof( AtkHyperlinkImplIface ) },
	{ "AtkHyperlinkClass", sizeof( AtkHyperlinkClass ) },
	{ "AtkHyperlink", sizeof( AtkHyperlink ) },
	{ "AtkGObjectAccessibleClass", sizeof( AtkGObjectAccessibleClass ) },
	{ "AtkGObjectAccessible", sizeof( AtkGObjectAccessible ) },
	{ "AtkEditableTextIface", sizeof( AtkEditableTextIface ) },
	{ "AtkTextRange", sizeof( AtkTextRange ) },
	{ "AtkTextRectangle", sizeof( AtkTextRectangle ) },
	{ "AtkTextIface", sizeof( AtkTextIface ) },
	{ "AtkDocumentIface", sizeof( AtkDocumentIface ) },
	{ "AtkRectangle", sizeof( AtkRectangle ) },
	{ "AtkComponentIface", sizeof( AtkComponentIface ) },
	{ "AtkKeyEventStruct", sizeof( AtkKeyEventStruct ) },
	{ "AtkUtilClass", sizeof( AtkUtilClass ) },
	{ "AtkUtil", sizeof( AtkUtil ) },
	{ "AtkActionIface", sizeof( AtkActionIface ) },
	{ "AtkPropertyValues", sizeof( AtkPropertyValues ) },
	{ "AtkStateSet", sizeof( AtkStateSet ) },
	{ "AtkRelationSet", sizeof( AtkRelationSet ) },
	{ "AtkObjectClass", sizeof( AtkObjectClass ) },
	{ "AtkObject", sizeof( AtkObject ) },
	{ "AtkImplementorIface", sizeof( AtkImplementorIface ) },
	{ "AtkAttribute", sizeof( AtkAttribute ) },
	{ "cairo_path_t", sizeof( cairo_path_t ) },
	{ "cairo_path_data_t", sizeof( cairo_path_data_t ) },
	{ "cairo_font_extents_t", sizeof( cairo_font_extents_t ) },
	{ "cairo_text_extents_t", sizeof( cairo_text_extents_t ) },
	{ "cairo_glyph_t", sizeof( cairo_glyph_t ) },
	{ "cairo_rectangle_list_t", sizeof( cairo_rectangle_list_t ) },
	{ "cairo_rectangle_t", sizeof( cairo_rectangle_t ) },
	{ "cairo_user_data_key_t", sizeof( cairo_user_data_key_t ) },
	{ "cairo_matrix_t", sizeof( cairo_matrix_t ) },
	{ "GdkWindowObjectClass", sizeof( GdkWindowObjectClass ) },
	{ "GdkWindowObject", sizeof( GdkWindowObject ) },
	{ "GdkPointerHooks", sizeof( GdkPointerHooks ) },
	{ "GdkWindowAttr", sizeof( GdkWindowAttr ) },
	{ "GdkGeometry", sizeof( GdkGeometry ) },
	{ "GdkScreenClass", sizeof( GdkScreenClass ) },
	{ "GdkPixmapObjectClass", sizeof( GdkPixmapObjectClass ) },
	{ "GdkPixmapObject", sizeof( GdkPixmapObject ) },
	{ "GdkPangoAttrEmbossColor", sizeof( GdkPangoAttrEmbossColor ) },
	{ "GdkPangoAttrEmbossed", sizeof( GdkPangoAttrEmbossed ) },
	{ "GdkPangoAttrStipple", sizeof( GdkPangoAttrStipple ) },
	{ "GdkPangoRendererClass", sizeof( GdkPangoRendererClass ) },
	{ "GdkPangoRenderer", sizeof( GdkPangoRenderer ) },
	{ "GdkDisplayManagerClass", sizeof( GdkDisplayManagerClass ) },
	{ "GdkKeymapClass", sizeof( GdkKeymapClass ) },
	{ "GdkKeymap", sizeof( GdkKeymap ) },
	{ "GdkKeymapKey", sizeof( GdkKeymapKey ) },
	{ "GdkImageClass", sizeof( GdkImageClass ) },
	{ "GdkTrapezoid", sizeof( GdkTrapezoid ) },
	{ "GdkDrawableClass", sizeof( GdkDrawableClass ) },
	{ "GdkGCClass", sizeof( GdkGCClass ) },
	{ "GdkGCValues", sizeof( GdkGCValues ) },
	{ "GdkDisplayPointerHooks", sizeof( GdkDisplayPointerHooks ) },
	{ "GdkDisplayClass", sizeof( GdkDisplayClass ) },
	{ "GdkEvent", sizeof( GdkEvent ) },
	{ "GdkEventGrabBroken", sizeof( GdkEventGrabBroken ) },
	{ "GdkEventSetting", sizeof( GdkEventSetting ) },
	{ "GdkEventWindowState", sizeof( GdkEventWindowState ) },
	{ "GdkEventDND", sizeof( GdkEventDND ) },
	{ "GdkEventClient", sizeof( GdkEventClient ) },
	{ "GdkEventProximity", sizeof( GdkEventProximity ) },
	{ "GdkEventOwnerChange", sizeof( GdkEventOwnerChange ) },
	{ "GdkEventSelection", sizeof( GdkEventSelection ) },
	{ "GdkEventProperty", sizeof( GdkEventProperty ) },
	{ "GdkEventConfigure", sizeof( GdkEventConfigure ) },
	{ "GdkEventCrossing", sizeof( GdkEventCrossing ) },
	{ "GdkEventFocus", sizeof( GdkEventFocus ) },
	{ "GdkEventKey", sizeof( GdkEventKey ) },
	{ "GdkEventScroll", sizeof( GdkEventScroll ) },
	{ "GdkEventButton", sizeof( GdkEventButton ) },
	{ "GdkEventMotion", sizeof( GdkEventMotion ) },
	{ "GdkEventVisibility", sizeof( GdkEventVisibility ) },
	{ "GdkEventNoExpose", sizeof( GdkEventNoExpose ) },
	{ "GdkEventExpose", sizeof( GdkEventExpose ) },
	{ "GdkEventAny", sizeof( GdkEventAny ) },
	{ "GdkTimeCoord", sizeof( GdkTimeCoord ) },
	{ "GdkDevice", sizeof( GdkDevice ) },
	{ "GdkDeviceAxis", sizeof( GdkDeviceAxis ) },
	{ "GdkDeviceKey", sizeof( GdkDeviceKey ) },
	{ "GdkDragContextClass", sizeof( GdkDragContextClass ) },
	{ "GdkDragContext", sizeof( GdkDragContext ) },
	{ "GdkPixbufLoaderClass", sizeof( GdkPixbufLoaderClass ) },
	{ "GdkPixbufLoader", sizeof( GdkPixbufLoader ) },
	{ "GdkRgbCmap", sizeof( GdkRgbCmap ) },
	{ "GdkColormapClass", sizeof( GdkColormapClass ) },
	{ "GdkScreen", sizeof( GdkScreen ) },
	{ "GdkDisplay", sizeof( GdkDisplay ) },
	{ "GdkDrawable", sizeof( GdkDrawable ) },
	{ "GdkVisual", sizeof( GdkVisual ) },
	{ "GdkImage", sizeof( GdkImage ) },
	{ "GdkGC", sizeof( GdkGC ) },
	{ "GdkFont", sizeof( GdkFont ) },
	{ "GdkCursor", sizeof( GdkCursor ) },
	{ "GdkColormap", sizeof( GdkColormap ) },
	{ "GdkColor", sizeof( GdkColor ) },
	{ "GdkSpan", sizeof( GdkSpan ) },
	{ "GdkSegment", sizeof( GdkSegment ) },
	{ "GdkRectangle", sizeof( GdkRectangle ) },
	{ "GdkPoint", sizeof( GdkPoint ) },
	{ "GStaticMutex", sizeof( GStaticMutex ) },
	{ "GSystemThread", sizeof( GSystemThread ) },
	{ "GValueArray", sizeof( GValueArray ) },
	{ "GTypePluginClass", sizeof( GTypePluginClass ) },
	{ "GTypeModuleClass", sizeof( GTypeModuleClass ) },
	{ "GTypeModule", sizeof( GTypeModule ) },
	{ "GParamSpecGType", sizeof( GParamSpecGType ) },
	{ "GParamSpecOverride", sizeof( GParamSpecOverride ) },
	{ "GParamSpecObject", sizeof( GParamSpecObject ) },
	{ "GParamSpecValueArray", sizeof( GParamSpecValueArray ) },
	{ "GParamSpecPointer", sizeof( GParamSpecPointer ) },
	{ "GParamSpecBoxed", sizeof( GParamSpecBoxed ) },
	{ "GParamSpecParam", sizeof( GParamSpecParam ) },
	{ "GParamSpecString", sizeof( GParamSpecString ) },
	{ "GParamSpecDouble", sizeof( GParamSpecDouble ) },
	{ "GParamSpecFloat", sizeof( GParamSpecFloat ) },
	{ "GParamSpecFlags", sizeof( GParamSpecFlags ) },
	{ "GParamSpecEnum", sizeof( GParamSpecEnum ) },
	{ "GParamSpecUnichar", sizeof( GParamSpecUnichar ) },
	{ "GParamSpecUInt64", sizeof( GParamSpecUInt64 ) },
	{ "GParamSpecInt64", sizeof( GParamSpecInt64 ) },
	{ "GParamSpecULong", sizeof( GParamSpecULong ) },
	{ "GParamSpecLong", sizeof( GParamSpecLong ) },
	{ "GParamSpecUInt", sizeof( GParamSpecUInt ) },
	{ "GParamSpecInt", sizeof( GParamSpecInt ) },
	{ "GParamSpecBoolean", sizeof( GParamSpecBoolean ) },
	{ "GParamSpecUChar", sizeof( GParamSpecUChar ) },
	{ "GParamSpecChar", sizeof( GParamSpecChar ) },
	{ "GObjectConstructParam", sizeof( GObjectConstructParam ) },
	{ "GObjectClass", sizeof( GObjectClass ) },
	{ "GObject", sizeof( GObject ) },
	{ "GSignalInvocationHint", sizeof( GSignalInvocationHint ) },
	{ "GSignalQuery", sizeof( GSignalQuery ) },
	{ "GCClosure", sizeof( GCClosure ) },
	{ "GClosureNotifyData", sizeof( GClosureNotifyData ) },
	{ "GClosure", sizeof( GClosure ) },
	{ "GParamSpecTypeInfo", sizeof( GParamSpecTypeInfo ) },
	{ "GParameter", sizeof( GParameter ) },
	{ "GParamSpecClass", sizeof( GParamSpecClass ) },
	{ "GParamSpec", sizeof( GParamSpec ) },
	{ "GFlagsValue", sizeof( GFlagsValue ) },
	{ "GEnumValue", sizeof( GEnumValue ) },
	{ "GFlagsClass", sizeof( GFlagsClass ) },
	{ "GEnumClass", sizeof( GEnumClass ) },
	{ "GTypeQuery", sizeof( GTypeQuery ) },
	{ "GTypeValueTable", sizeof( GTypeValueTable ) },
	{ "GInterfaceInfo", sizeof( GInterfaceInfo ) },
	{ "GTypeFundamentalInfo", sizeof( GTypeFundamentalInfo ) },
	{ "GTypeInfo", sizeof( GTypeInfo ) },
	{ "GTypeInstance", sizeof( GTypeInstance ) },
	{ "GTypeInterface", sizeof( GTypeInterface ) },
	{ "GTypeClass", sizeof( GTypeClass ) },
	{ "GValue", sizeof( GValue ) },
	{ "GThreadPool", sizeof( GThreadPool ) },
	{ "GTokenValue", sizeof( GTokenValue ) },
	{ "GScannerConfig", sizeof( GScannerConfig ) },
	{ "GScanner", sizeof( GScanner ) },
	{ "GTuples", sizeof( GTuples ) },
	{ "GQueue", sizeof( GQueue ) },
	{ "GOptionEntry", sizeof( GOptionEntry ) },
	{ "GNode", sizeof( GNode ) },
	{ "GMarkupParser", sizeof( GMarkupParser ) },
	{ "GIOFuncs", sizeof( GIOFuncs ) },
	{ "GIOChannel", sizeof( GIOChannel ) },
	{ "GString", sizeof( GString ) },
	{ "GPollFD", sizeof( GPollFD ) },
	{ "GSourceFuncs", sizeof( GSourceFuncs ) },
	{ "GSourceCallbackFuncs", sizeof( GSourceCallbackFuncs ) },
	{ "GSource", sizeof( GSource ) },
	{ "GSList", sizeof( GSList ) },
	{ "GHookList", sizeof( GHookList ) },
	{ "GHook", sizeof( GHook ) },
	{ "GDate", sizeof( GDate ) },
	{ "GCompletion", sizeof( GCompletion ) },
	{ "GList", sizeof( GList ) },
	{ "GMemVTable", sizeof( GMemVTable ) },
	{ "GOnce", sizeof( GOnce ) },
	{ "GStaticRWLock", sizeof( GStaticRWLock ) },
	{ "GStaticRecMutex", sizeof( GStaticRecMutex ) },
	{ "GThreadFunctions", sizeof( GThreadFunctions ) },
	{ "GStaticPrivate", sizeof( GStaticPrivate ) },
	{ "GThread", sizeof( GThread ) },
	{ "GTrashStack", sizeof( GTrashStack ) },
	{ "GDebugKey", sizeof( GDebugKey ) },
	{ "GError", sizeof( GError ) },
	{ "GPtrArray", sizeof( GPtrArray ) },
	{ "GByteArray", sizeof( GByteArray ) },
	{ "GArray", sizeof( GArray ) },
	{ "GTimeVal", sizeof( GTimeVal ) },
	{ "GFloatIEEE754", sizeof( GFloatIEEE754 ) },
	{ "GDoubleIEEE754", sizeof( GDoubleIEEE754 ) },
	{ "GLXEvent", sizeof( GLXEvent ) },
	{ "GLXPbufferClobberEvent", sizeof( GLXPbufferClobberEvent ) },
	{ "GtkVSeparatorClass", sizeof( GtkVSeparatorClass ) },
	{ "GtkVSeparator", sizeof( GtkVSeparator ) },
	{ "GtkVScaleClass", sizeof( GtkVScaleClass ) },
	{ "GtkVScale", sizeof( GtkVScale ) },
	{ "GtkVRulerClass", sizeof( GtkVRulerClass ) },
	{ "GtkVRuler", sizeof( GtkVRuler ) },
	{ "GtkVPanedClass", sizeof( GtkVPanedClass ) },
	{ "GtkVPaned", sizeof( GtkVPaned ) },
	{ "GtkVolumeButtonClass", sizeof( GtkVolumeButtonClass ) },
	{ "GtkVButtonBoxClass", sizeof( GtkVButtonBoxClass ) },
	{ "GtkVButtonBox", sizeof( GtkVButtonBox ) },
	{ "GtkUIManagerClass", sizeof( GtkUIManagerClass ) },
	{ "GtkUIManager", sizeof( GtkUIManager ) },
	{ "GtkTreeStoreClass", sizeof( GtkTreeStoreClass ) },
	{ "GtkTreeStore", sizeof( GtkTreeStore ) },
	{ "GtkTreeModelSortClass", sizeof( GtkTreeModelSortClass ) },
	{ "GtkTreeModelSort", sizeof( GtkTreeModelSort ) },
	{ "GtkTreeDragDestIface", sizeof( GtkTreeDragDestIface ) },
	{ "GtkTreeDragSourceIface", sizeof( GtkTreeDragSourceIface ) },
	{ "GtkToolbarClass", sizeof( GtkToolbarClass ) },
	{ "GtkToolbar", sizeof( GtkToolbar ) },
	{ "GtkToolbarChild", sizeof( GtkToolbarChild ) },
	{ "GtkTipsQueryClass", sizeof( GtkTipsQueryClass ) },
	{ "GtkTipsQuery", sizeof( GtkTipsQuery ) },
	{ "GtkTextViewClass", sizeof( GtkTextViewClass ) },
	{ "GtkTextView", sizeof( GtkTextView ) },
	{ "GtkTextBufferClass", sizeof( GtkTextBufferClass ) },
	{ "GtkTextMarkClass", sizeof( GtkTextMarkClass ) },
	{ "GtkTextMark", sizeof( GtkTextMark ) },
	{ "GtkTextTagTableClass", sizeof( GtkTextTagTableClass ) },
	{ "GtkTearoffMenuItemClass", sizeof( GtkTearoffMenuItemClass ) },
	{ "GtkTearoffMenuItem", sizeof( GtkTearoffMenuItem ) },
	{ "GtkTableRowCol", sizeof( GtkTableRowCol ) },
	{ "GtkTableChild", sizeof( GtkTableChild ) },
	{ "GtkTableClass", sizeof( GtkTableClass ) },
	{ "GtkTable", sizeof( GtkTable ) },
	{ "GtkStockItem", sizeof( GtkStockItem ) },
	{ "GtkStatusIconClass", sizeof( GtkStatusIconClass ) },
	{ "GtkStatusIcon", sizeof( GtkStatusIcon ) },
	{ "GtkStatusbarClass", sizeof( GtkStatusbarClass ) },
	{ "GtkStatusbar", sizeof( GtkStatusbar ) },
	{ "GtkSpinButtonClass", sizeof( GtkSpinButtonClass ) },
	{ "GtkSpinButton", sizeof( GtkSpinButton ) },
	{ "GtkSizeGroupClass", sizeof( GtkSizeGroupClass ) },
	{ "GtkSizeGroup", sizeof( GtkSizeGroup ) },
	{ "GtkSeparatorToolItemClass", sizeof( GtkSeparatorToolItemClass ) },
	{ "GtkSeparatorToolItem", sizeof( GtkSeparatorToolItem ) },
	{ "GtkSeparatorMenuItemClass", sizeof( GtkSeparatorMenuItemClass ) },
	{ "GtkSeparatorMenuItem", sizeof( GtkSeparatorMenuItem ) },
	{ "GtkScrolledWindowClass", sizeof( GtkScrolledWindowClass ) },
	{ "GtkScrolledWindow", sizeof( GtkScrolledWindow ) },
	{ "GtkViewportClass", sizeof( GtkViewportClass ) },
	{ "GtkViewport", sizeof( GtkViewport ) },
	{ "GtkScaleButtonClass", sizeof( GtkScaleButtonClass ) },
	{ "GtkScaleButton", sizeof( GtkScaleButton ) },
	{ "GtkRecentChooserWidgetClass", sizeof( GtkRecentChooserWidgetClass ) },
	{ "GtkRecentChooserWidget", sizeof( GtkRecentChooserWidget ) },
	{ "GtkRecentChooserMenuClass", sizeof( GtkRecentChooserMenuClass ) },
	{ "GtkRecentChooserMenu", sizeof( GtkRecentChooserMenu ) },
	{ "GtkRecentChooserDialogClass", sizeof( GtkRecentChooserDialogClass ) },
	{ "GtkRecentChooserDialog", sizeof( GtkRecentChooserDialog ) },
	{ "GtkRecentChooserIface", sizeof( GtkRecentChooserIface ) },
	{ "GtkRecentFilterInfo", sizeof( GtkRecentFilterInfo ) },
	{ "GtkRecentActionClass", sizeof( GtkRecentActionClass ) },
	{ "GtkRecentAction", sizeof( GtkRecentAction ) },
	{ "GtkRecentManagerClass", sizeof( GtkRecentManagerClass ) },
	{ "GtkRecentManager", sizeof( GtkRecentManager ) },
	{ "GtkRecentData", sizeof( GtkRecentData ) },
	{ "GtkRadioToolButtonClass", sizeof( GtkRadioToolButtonClass ) },
	{ "GtkRadioToolButton", sizeof( GtkRadioToolButton ) },
	{ "GtkToggleToolButtonClass", sizeof( GtkToggleToolButtonClass ) },
	{ "GtkToggleToolButton", sizeof( GtkToggleToolButton ) },
	{ "GtkRadioMenuItemClass", sizeof( GtkRadioMenuItemClass ) },
	{ "GtkRadioMenuItem", sizeof( GtkRadioMenuItem ) },
	{ "GtkRadioButtonClass", sizeof( GtkRadioButtonClass ) },
	{ "GtkRadioButton", sizeof( GtkRadioButton ) },
	{ "GtkRadioActionClass", sizeof( GtkRadioActionClass ) },
	{ "GtkRadioAction", sizeof( GtkRadioAction ) },
	{ "GtkToggleActionClass", sizeof( GtkToggleActionClass ) },
	{ "GtkToggleAction", sizeof( GtkToggleAction ) },
	{ "GtkProgressBarClass", sizeof( GtkProgressBarClass ) },
	{ "GtkProgressBar", sizeof( GtkProgressBar ) },
	{ "GtkProgressClass", sizeof( GtkProgressClass ) },
	{ "GtkProgress", sizeof( GtkProgress ) },
	{ "GtkPrintOperation", sizeof( GtkPrintOperation ) },
	{ "GtkPrintOperationClass", sizeof( GtkPrintOperationClass ) },
	{ "GtkPrintOperationPreviewIface", sizeof( GtkPrintOperationPreviewIface ) },
	{ "GtkPageRange", sizeof( GtkPageRange ) },
	{ "GtkPreviewClass", sizeof( GtkPreviewClass ) },
	{ "GtkDitherInfo", sizeof( GtkDitherInfo ) },
	{ "GtkPreviewInfo", sizeof( GtkPreviewInfo ) },
	{ "GtkPreview", sizeof( GtkPreview ) },
	{ "GtkPlugClass", sizeof( GtkPlugClass ) },
	{ "GtkPlug", sizeof( GtkPlug ) },
	{ "GtkSocketClass", sizeof( GtkSocketClass ) },
	{ "GtkSocket", sizeof( GtkSocket ) },
	{ "GtkPixmapClass", sizeof( GtkPixmapClass ) },
	{ "GtkPixmap", sizeof( GtkPixmap ) },
	{ "GtkOptionMenuClass", sizeof( GtkOptionMenuClass ) },
	{ "GtkOptionMenu", sizeof( GtkOptionMenu ) },
	{ "GtkOldEditableClass", sizeof( GtkOldEditableClass ) },
	{ "GtkOldEditable", sizeof( GtkOldEditable ) },
	{ "GtkNotebookClass", sizeof( GtkNotebookClass ) },
	{ "GtkNotebook", sizeof( GtkNotebook ) },
	{ "GtkMessageDialogClass", sizeof( GtkMessageDialogClass ) },
	{ "GtkMessageDialog", sizeof( GtkMessageDialog ) },
	{ "GtkMenuToolButton", sizeof( GtkMenuToolButton ) },
	{ "GtkMenuToolButtonClass", sizeof( GtkMenuToolButtonClass ) },
	{ "GtkToolButtonClass", sizeof( GtkToolButtonClass ) },
	{ "GtkToolButton", sizeof( GtkToolButton ) },
	{ "GtkToolItemClass", sizeof( GtkToolItemClass ) },
	{ "GtkToolItem", sizeof( GtkToolItem ) },
	{ "GtkTooltipsData", sizeof( GtkTooltipsData ) },
	{ "GtkTooltipsClass", sizeof( GtkTooltipsClass ) },
	{ "GtkTooltips", sizeof( GtkTooltips ) },
	{ "GtkMenuBarClass", sizeof( GtkMenuBarClass ) },
	{ "GtkMenuBar", sizeof( GtkMenuBar ) },
	{ "GtkListClass", sizeof( GtkListClass ) },
	{ "GtkList", sizeof( GtkList ) },
	{ "GtkListItemClass", sizeof( GtkListItemClass ) },
	{ "GtkListItem", sizeof( GtkListItem ) },
	{ "GtkLinkButtonClass", sizeof( GtkLinkButtonClass ) },
	{ "GtkLinkButton", sizeof( GtkLinkButton ) },
	{ "GtkLayoutClass", sizeof( GtkLayoutClass ) },
	{ "GtkLayout", sizeof( GtkLayout ) },
	{ "GtkInvisibleClass", sizeof( GtkInvisibleClass ) },
	{ "GtkInvisible", sizeof( GtkInvisible ) },
	{ "GtkInputDialogClass", sizeof( GtkInputDialogClass ) },
	{ "GtkInputDialog", sizeof( GtkInputDialog ) },
	{ "GtkIMMulticontextClass", sizeof( GtkIMMulticontextClass ) },
	{ "GtkIMMulticontext", sizeof( GtkIMMulticontext ) },
	{ "GtkIMContextSimpleClass", sizeof( GtkIMContextSimpleClass ) },
	{ "GtkIMContextSimple", sizeof( GtkIMContextSimple ) },
	{ "GtkImageMenuItemClass", sizeof( GtkImageMenuItemClass ) },
	{ "GtkImageMenuItem", sizeof( GtkImageMenuItem ) },
	{ "GtkIconViewClass", sizeof( GtkIconViewClass ) },
	{ "GtkIconView", sizeof( GtkIconView ) },
	{ "GtkIconThemeClass", sizeof( GtkIconThemeClass ) },
	{ "GtkIconTheme", sizeof( GtkIconTheme ) },
	{ "GtkIconFactoryClass", sizeof( GtkIconFactoryClass ) },
	{ "GtkHSeparatorClass", sizeof( GtkHSeparatorClass ) },
	{ "GtkHSeparator", sizeof( GtkHSeparator ) },
	{ "GtkSeparatorClass", sizeof( GtkSeparatorClass ) },
	{ "GtkSeparator", sizeof( GtkSeparator ) },
	{ "GtkHScaleClass", sizeof( GtkHScaleClass ) },
	{ "GtkHScale", sizeof( GtkHScale ) },
	{ "GtkScaleClass", sizeof( GtkScaleClass ) },
	{ "GtkScale", sizeof( GtkScale ) },
	{ "GtkHRulerClass", sizeof( GtkHRulerClass ) },
	{ "GtkHRuler", sizeof( GtkHRuler ) },
	{ "GtkRulerMetric", sizeof( GtkRulerMetric ) },
	{ "GtkRulerClass", sizeof( GtkRulerClass ) },
	{ "GtkRuler", sizeof( GtkRuler ) },
	{ "GtkHPanedClass", sizeof( GtkHPanedClass ) },
	{ "GtkHPaned", sizeof( GtkHPaned ) },
	{ "GtkPanedClass", sizeof( GtkPanedClass ) },
	{ "GtkPaned", sizeof( GtkPaned ) },
	{ "GtkHButtonBoxClass", sizeof( GtkHButtonBoxClass ) },
	{ "GtkHButtonBox", sizeof( GtkHButtonBox ) },
	{ "GtkHandleBoxClass", sizeof( GtkHandleBoxClass ) },
	{ "GtkHandleBox", sizeof( GtkHandleBox ) },
	{ "GtkGammaCurveClass", sizeof( GtkGammaCurveClass ) },
	{ "GtkGammaCurve", sizeof( GtkGammaCurve ) },
	{ "GtkFontSelectionDialogClass", sizeof( GtkFontSelectionDialogClass ) },
	{ "GtkFontSelectionDialog", sizeof( GtkFontSelectionDialog ) },
	{ "GtkFontSelectionClass", sizeof( GtkFontSelectionClass ) },
	{ "GtkFontSelection", sizeof( GtkFontSelection ) },
	{ "GtkFontButtonClass", sizeof( GtkFontButtonClass ) },
	{ "GtkFontButton", sizeof( GtkFontButton ) },
	{ "GtkFileChooserWidgetClass", sizeof( GtkFileChooserWidgetClass ) },
	{ "GtkFileChooserWidget", sizeof( GtkFileChooserWidget ) },
	{ "GtkFileChooserDialogClass", sizeof( GtkFileChooserDialogClass ) },
	{ "GtkFileChooserDialog", sizeof( GtkFileChooserDialog ) },
	{ "GtkFileChooserButtonClass", sizeof( GtkFileChooserButtonClass ) },
	{ "GtkFileChooserButton", sizeof( GtkFileChooserButton ) },
	{ "GtkFileFilterInfo", sizeof( GtkFileFilterInfo ) },
	{ "GtkFixedChild", sizeof( GtkFixedChild ) },
	{ "GtkFixedClass", sizeof( GtkFixedClass ) },
	{ "GtkFixed", sizeof( GtkFixed ) },
	{ "GtkFileSelectionClass", sizeof( GtkFileSelectionClass ) },
	{ "GtkFileSelection", sizeof( GtkFileSelection ) },
	{ "GtkExpanderClass", sizeof( GtkExpanderClass ) },
	{ "GtkExpander", sizeof( GtkExpander ) },
	{ "GtkEventBoxClass", sizeof( GtkEventBoxClass ) },
	{ "GtkEventBox", sizeof( GtkEventBox ) },
	{ "GtkCurveClass", sizeof( GtkCurveClass ) },
	{ "GtkCurve", sizeof( GtkCurve ) },
	{ "GtkDrawingAreaClass", sizeof( GtkDrawingAreaClass ) },
	{ "GtkDrawingArea", sizeof( GtkDrawingArea ) },
	{ "GtkCTreeNode", sizeof( GtkCTreeNode ) },
	{ "GtkCTreeRow", sizeof( GtkCTreeRow ) },
	{ "GtkCTreeClass", sizeof( GtkCTreeClass ) },
	{ "GtkCTree", sizeof( GtkCTree ) },
	{ "GtkComboBoxEntryClass", sizeof( GtkComboBoxEntryClass ) },
	{ "GtkComboBoxEntry", sizeof( GtkComboBoxEntry ) },
	{ "GtkComboBoxClass", sizeof( GtkComboBoxClass ) },
	{ "GtkComboBox", sizeof( GtkComboBox ) },
	{ "GtkTreeSelectionClass", sizeof( GtkTreeSelectionClass ) },
	{ "GtkTreeSelection", sizeof( GtkTreeSelection ) },
	{ "GtkTreeViewClass", sizeof( GtkTreeViewClass ) },
	{ "GtkTreeView", sizeof( GtkTreeView ) },
	{ "GtkEntryClass", sizeof( GtkEntryClass ) },
	{ "GtkEntry", sizeof( GtkEntry ) },
	{ "GtkEntryCompletionClass", sizeof( GtkEntryCompletionClass ) },
	{ "GtkEntryCompletion", sizeof( GtkEntryCompletion ) },
	{ "GtkTreeModelFilterClass", sizeof( GtkTreeModelFilterClass ) },
	{ "GtkTreeModelFilter", sizeof( GtkTreeModelFilter ) },
	{ "GtkListStoreClass", sizeof( GtkListStoreClass ) },
	{ "GtkListStore", sizeof( GtkListStore ) },
	{ "GtkIMContextClass", sizeof( GtkIMContextClass ) },
	{ "GtkIMContext", sizeof( GtkIMContext ) },
	{ "GtkEditableClass", sizeof( GtkEditableClass ) },
	{ "GtkComboClass", sizeof( GtkComboClass ) },
	{ "GtkCombo", sizeof( GtkCombo ) },
	{ "GtkHBoxClass", sizeof( GtkHBoxClass ) },
	{ "GtkHBox", sizeof( GtkHBox ) },
	{ "GtkColorSelectionDialogClass", sizeof( GtkColorSelectionDialogClass ) },
	{ "GtkColorSelectionDialog", sizeof( GtkColorSelectionDialog ) },
	{ "GtkColorSelectionClass", sizeof( GtkColorSelectionClass ) },
	{ "GtkColorSelection", sizeof( GtkColorSelection ) },
	{ "GtkVBoxClass", sizeof( GtkVBoxClass ) },
	{ "GtkVBox", sizeof( GtkVBox ) },
	{ "GtkColorButtonClass", sizeof( GtkColorButtonClass ) },
	{ "GtkColorButton", sizeof( GtkColorButton ) },
	{ "GtkCListDestInfo", sizeof( GtkCListDestInfo ) },
	{ "GtkCListCellInfo", sizeof( GtkCListCellInfo ) },
	{ "GtkCellWidget", sizeof( GtkCellWidget ) },
	{ "GtkCellPixText", sizeof( GtkCellPixText ) },
	{ "GtkCellPixmap", sizeof( GtkCellPixmap ) },
	{ "GtkCellText", sizeof( GtkCellText ) },
	{ "GtkCell", sizeof( GtkCell ) },
	{ "GtkCListRow", sizeof( GtkCListRow ) },
	{ "GtkCListColumn", sizeof( GtkCListColumn ) },
	{ "GtkCListClass", sizeof( GtkCListClass ) },
	{ "GtkCList", sizeof( GtkCList ) },
	{ "GtkVScrollbarClass", sizeof( GtkVScrollbarClass ) },
	{ "GtkVScrollbar", sizeof( GtkVScrollbar ) },
	{ "GtkHScrollbarClass", sizeof( GtkHScrollbarClass ) },
	{ "GtkHScrollbar", sizeof( GtkHScrollbar ) },
	{ "GtkScrollbarClass", sizeof( GtkScrollbarClass ) },
	{ "GtkScrollbar", sizeof( GtkScrollbar ) },
	{ "GtkRangeClass", sizeof( GtkRangeClass ) },
	{ "GtkRange", sizeof( GtkRange ) },
	{ "GtkTargetPair", sizeof( GtkTargetPair ) },
	{ "GtkTargetEntry", sizeof( GtkTargetEntry ) },
	{ "GtkTargetList", sizeof( GtkTargetList ) },
	{ "GtkTextBuffer", sizeof( GtkTextBuffer ) },
	{ "GtkTextChildAnchorClass", sizeof( GtkTextChildAnchorClass ) },
	{ "GtkTextChildAnchor", sizeof( GtkTextChildAnchor ) },
	{ "GtkTextAppearance", sizeof( GtkTextAppearance ) },
	{ "GtkTextTagClass", sizeof( GtkTextTagClass ) },
	{ "GtkTextTag", sizeof( GtkTextTag ) },
	{ "GtkTextAttributes", sizeof( GtkTextAttributes ) },
	{ "GtkTextTagTable", sizeof( GtkTextTagTable ) },
	{ "GtkTextIter", sizeof( GtkTextIter ) },
	{ "GtkCheckMenuItemClass", sizeof( GtkCheckMenuItemClass ) },
	{ "GtkCheckMenuItem", sizeof( GtkCheckMenuItem ) },
	{ "GtkMenuItemClass", sizeof( GtkMenuItemClass ) },
	{ "GtkMenuItem", sizeof( GtkMenuItem ) },
	{ "GtkItemClass", sizeof( GtkItemClass ) },
	{ "GtkItem", sizeof( GtkItem ) },
	{ "GtkCheckButtonClass", sizeof( GtkCheckButtonClass ) },
	{ "GtkCheckButton", sizeof( GtkCheckButton ) },
	{ "GtkToggleButtonClass", sizeof( GtkToggleButtonClass ) },
	{ "GtkToggleButton", sizeof( GtkToggleButton ) },
	{ "GtkCellViewClass", sizeof( GtkCellViewClass ) },
	{ "GtkCellView", sizeof( GtkCellView ) },
	{ "GtkCellRendererToggleClass", sizeof( GtkCellRendererToggleClass ) },
	{ "GtkCellRendererToggle", sizeof( GtkCellRendererToggle ) },
	{ "GtkCellRendererSpinClass", sizeof( GtkCellRendererSpinClass ) },
	{ "GtkCellRendererSpin", sizeof( GtkCellRendererSpin ) },
	{ "GtkCellRendererProgressClass", sizeof( GtkCellRendererProgressClass ) },
	{ "GtkCellRendererProgress", sizeof( GtkCellRendererProgress ) },
	{ "GtkCellRendererPixbufClass", sizeof( GtkCellRendererPixbufClass ) },
	{ "GtkCellRendererPixbuf", sizeof( GtkCellRendererPixbuf ) },
	{ "GtkCellRendererComboClass", sizeof( GtkCellRendererComboClass ) },
	{ "GtkCellRendererCombo", sizeof( GtkCellRendererCombo ) },
	{ "GtkCellRendererAccelClass", sizeof( GtkCellRendererAccelClass ) },
	{ "GtkCellRendererAccel", sizeof( GtkCellRendererAccel ) },
	{ "GtkCellRendererTextClass", sizeof( GtkCellRendererTextClass ) },
	{ "GtkCellRendererText", sizeof( GtkCellRendererText ) },
	{ "GtkCellLayoutIface", sizeof( GtkCellLayoutIface ) },
	{ "GtkTreeViewColumnClass", sizeof( GtkTreeViewColumnClass ) },
	{ "GtkTreeViewColumn", sizeof( GtkTreeViewColumn ) },
	{ "GtkTreeSortableIface", sizeof( GtkTreeSortableIface ) },
	{ "GtkTreeModelIface", sizeof( GtkTreeModelIface ) },
	{ "GtkTreeIter", sizeof( GtkTreeIter ) },
	{ "GtkCellRendererClass", sizeof( GtkCellRendererClass ) },
	{ "GtkCellRenderer", sizeof( GtkCellRenderer ) },
	{ "GtkCellEditableIface", sizeof( GtkCellEditableIface ) },
	{ "GtkCalendarClass", sizeof( GtkCalendarClass ) },
	{ "GtkCalendar", sizeof( GtkCalendar ) },
	{ "GtkButtonClass", sizeof( GtkButtonClass ) },
	{ "GtkButton", sizeof( GtkButton ) },
	{ "GtkImageIconNameData", sizeof( GtkImageIconNameData ) },
	{ "GtkImageAnimationData", sizeof( GtkImageAnimationData ) },
	{ "GtkImageIconSetData", sizeof( GtkImageIconSetData ) },
	{ "GtkImageStockData", sizeof( GtkImageStockData ) },
	{ "GtkImagePixbufData", sizeof( GtkImagePixbufData ) },
	{ "GtkImageImageData", sizeof( GtkImageImageData ) },
	{ "GtkImagePixmapData", sizeof( GtkImagePixmapData ) },
	{ "GtkImageClass", sizeof( GtkImageClass ) },
	{ "GtkImage", sizeof( GtkImage ) },
	{ "GtkBuildableIface", sizeof( GtkBuildableIface ) },
	{ "GtkBuilderClass", sizeof( GtkBuilderClass ) },
	{ "GtkBuilder", sizeof( GtkBuilder ) },
	{ "GtkBindingArg", sizeof( GtkBindingArg ) },
	{ "GtkBindingSignal", sizeof( GtkBindingSignal ) },
	{ "GtkBindingEntry", sizeof( GtkBindingEntry ) },
	{ "GtkBindingSet", sizeof( GtkBindingSet ) },
	{ "GtkButtonBoxClass", sizeof( GtkButtonBoxClass ) },
	{ "GtkButtonBox", sizeof( GtkButtonBox ) },
	{ "GtkBoxChild", sizeof( GtkBoxChild ) },
	{ "GtkBoxClass", sizeof( GtkBoxClass ) },
	{ "GtkBox", sizeof( GtkBox ) },
	{ "GtkAssistantClass", sizeof( GtkAssistantClass ) },
	{ "GtkAssistant", sizeof( GtkAssistant ) },
	{ "GtkAspectFrameClass", sizeof( GtkAspectFrameClass ) },
	{ "GtkAspectFrame", sizeof( GtkAspectFrame ) },
	{ "GtkFrameClass", sizeof( GtkFrameClass ) },
	{ "GtkFrame", sizeof( GtkFrame ) },
	{ "GtkArrowClass", sizeof( GtkArrowClass ) },
	{ "GtkArrow", sizeof( GtkArrow ) },
	{ "GtkAlignmentClass", sizeof( GtkAlignmentClass ) },
	{ "GtkAlignment", sizeof( GtkAlignment ) },
	{ "GtkRadioActionEntry", sizeof( GtkRadioActionEntry ) },
	{ "GtkToggleActionEntry", sizeof( GtkToggleActionEntry ) },
	{ "GtkActionEntry", sizeof( GtkActionEntry ) },
	{ "GtkActionGroupClass", sizeof( GtkActionGroupClass ) },
	{ "GtkActionGroup", sizeof( GtkActionGroup ) },
	{ "GtkMenuEntry", sizeof( GtkMenuEntry ) },
	{ "GtkItemFactoryItem", sizeof( GtkItemFactoryItem ) },
	{ "GtkItemFactoryEntry", sizeof( GtkItemFactoryEntry ) },
	{ "GtkItemFactoryClass", sizeof( GtkItemFactoryClass ) },
	{ "GtkItemFactory", sizeof( GtkItemFactory ) },
	{ "GtkActionClass", sizeof( GtkActionClass ) },
	{ "GtkAction", sizeof( GtkAction ) },
	{ "GtkAccessibleClass", sizeof( GtkAccessibleClass ) },
	{ "GtkAccessible", sizeof( GtkAccessible ) },
	{ "GtkAccelLabelClass", sizeof( GtkAccelLabelClass ) },
	{ "GtkAccelLabel", sizeof( GtkAccelLabel ) },
	{ "GtkLabelClass", sizeof( GtkLabelClass ) },
	{ "GtkLabel", sizeof( GtkLabel ) },
	{ "GtkMenuClass", sizeof( GtkMenuClass ) },
	{ "GtkMenu", sizeof( GtkMenu ) },
	{ "GtkMenuShellClass", sizeof( GtkMenuShellClass ) },
	{ "GtkMenuShell", sizeof( GtkMenuShell ) },
	{ "GtkMiscClass", sizeof( GtkMiscClass ) },
	{ "GtkMisc", sizeof( GtkMisc ) },
	{ "GtkAboutDialogClass", sizeof( GtkAboutDialogClass ) },
	{ "GtkAboutDialog", sizeof( GtkAboutDialog ) },
	{ "GtkDialogClass", sizeof( GtkDialogClass ) },
	{ "GtkDialog", sizeof( GtkDialog ) },
	{ "GtkWindowGroupClass", sizeof( GtkWindowGroupClass ) },
	{ "GtkWindowGroup", sizeof( GtkWindowGroup ) },
	{ "GtkWindowClass", sizeof( GtkWindowClass ) },
	{ "GtkBinClass", sizeof( GtkBinClass ) },
	{ "GtkBin", sizeof( GtkBin ) },
	{ "GtkContainerClass", sizeof( GtkContainerClass ) },
	{ "GtkContainer", sizeof( GtkContainer ) },
	{ "GtkWindow", sizeof( GtkWindow ) },
	{ "GtkWidgetShapeInfo", sizeof( GtkWidgetShapeInfo ) },
	{ "GtkWidgetAuxInfo", sizeof( GtkWidgetAuxInfo ) },
	{ "GtkWidgetClass", sizeof( GtkWidgetClass ) },
	{ "GtkSelectionData", sizeof( GtkSelectionData ) },
	{ "GtkRequisition", sizeof( GtkRequisition ) },
	{ "GtkSettingsValue", sizeof( GtkSettingsValue ) },
	{ "GtkSettingsClass", sizeof( GtkSettingsClass ) },
	{ "GtkRcStyleClass", sizeof( GtkRcStyleClass ) },
	{ "GtkIconFactory", sizeof( GtkIconFactory ) },
	{ "GtkWidget", sizeof( GtkWidget ) },
	{ "GtkSettings", sizeof( GtkSettings ) },
	{ "GtkRcProperty", sizeof( GtkRcProperty ) },
	{ "GtkRcStyle", sizeof( GtkRcStyle ) },
	{ "GtkStyleClass", sizeof( GtkStyleClass ) },
	{ "GtkStyle", sizeof( GtkStyle ) },
	{ "GtkBorder", sizeof( GtkBorder ) },
	{ "GtkAdjustmentClass", sizeof( GtkAdjustmentClass ) },
	{ "GtkAdjustment", sizeof( GtkAdjustment ) },
	{ "GtkObjectClass", sizeof( GtkObjectClass ) },
	{ "GtkTypeInfo", sizeof( GtkTypeInfo ) },
	{ "GtkObject", sizeof( GtkObject ) },
	{ "GtkArg", sizeof( GtkArg ) },
	{ "GtkAccelGroupEntry", sizeof( GtkAccelGroupEntry ) },
	{ "GtkAccelKey", sizeof( GtkAccelKey ) },
	{ "GtkAccelGroupClass", sizeof( GtkAccelGroupClass ) },
	{ "GtkAccelGroup", sizeof( GtkAccelGroup ) },
	{ "GtkPrintUnixDialogClass", sizeof( GtkPrintUnixDialogClass ) },
	{ "GtkPrintUnixDialog", sizeof( GtkPrintUnixDialog ) },
	{ "GtkPrintJobClass", sizeof( GtkPrintJobClass ) },
	{ "GtkPrintJob", sizeof( GtkPrintJob ) },
	{ "GtkPrinterClass", sizeof( GtkPrinterClass ) },
	{ "GtkPrinter", sizeof( GtkPrinter ) },
	{ "GtkPageSetupUnixDialogClass", sizeof( GtkPageSetupUnixDialogClass ) },
	{ "GtkPageSetupUnixDialog", sizeof( GtkPageSetupUnixDialog ) },
	{ "PangoRendererClass", sizeof( PangoRendererClass ) },
	{ "PangoRenderer", sizeof( PangoRenderer ) },
	{ "PangoLayoutLine", sizeof( PangoLayoutLine ) },
	{ "PangoGlyphItem", sizeof( PangoGlyphItem ) },
	{ "PangoGlyphString", sizeof( PangoGlyphString ) },
	{ "PangoGlyphInfo", sizeof( PangoGlyphInfo ) },
	{ "PangoGlyphVisAttr", sizeof( PangoGlyphVisAttr ) },
	{ "PangoGlyphGeometry", sizeof( PangoGlyphGeometry ) },
	{ "PangoItem", sizeof( PangoItem ) },
	{ "PangoAnalysis", sizeof( PangoAnalysis ) },
	{ "PangoAttrShape", sizeof( PangoAttrShape ) },
	{ "PangoAttrFontDesc", sizeof( PangoAttrFontDesc ) },
	{ "PangoAttrColor", sizeof( PangoAttrColor ) },
	{ "PangoAttrFloat", sizeof( PangoAttrFloat ) },
	{ "PangoAttrSize", sizeof( PangoAttrSize ) },
	{ "PangoAttrInt", sizeof( PangoAttrInt ) },
	{ "PangoAttrLanguage", sizeof( PangoAttrLanguage ) },
	{ "PangoAttrString", sizeof( PangoAttrString ) },
	{ "PangoAttrClass", sizeof( PangoAttrClass ) },
	{ "PangoAttribute", sizeof( PangoAttribute ) },
	{ "PangoColor", sizeof( PangoColor ) },
	{ "PangoMatrix", sizeof( PangoMatrix ) },
	{ "PangoRectangle", sizeof( PangoRectangle ) },
	{ "PangoLogAttr", sizeof( PangoLogAttr ) },
	{ "XExtensionVersion", sizeof( XExtensionVersion ) },
	{ "XButtonState", sizeof( XButtonState ) },
	{ "XKeyState", sizeof( XKeyState ) },
	{ "XValuatorState", sizeof( XValuatorState ) },
	{ "XDeviceState", sizeof( XDeviceState ) },
	{ "XDeviceTimeCoord", sizeof( XDeviceTimeCoord ) },
	{ "XEventList", sizeof( XEventList ) },
	{ "XDevice", sizeof( XDevice ) },
	{ "XInputClassInfo", sizeof( XInputClassInfo ) },
	{ "XValuatorInfo", sizeof( XValuatorInfo ) },
	{ "XAxisInfo", sizeof( XAxisInfo ) },
	{ "XButtonInfo", sizeof( XButtonInfo ) },
	{ "XKeyInfo", sizeof( XKeyInfo ) },
	{ "XDeviceInfo", sizeof( XDeviceInfo ) },
	{ "XDeviceEnableControl", sizeof( XDeviceEnableControl ) },
	{ "XDeviceCoreState", sizeof( XDeviceCoreState ) },
	{ "XDeviceCoreControl", sizeof( XDeviceCoreControl ) },
	{ "XDeviceAbsAreaControl", sizeof( XDeviceAbsAreaControl ) },
	{ "XDeviceAbsCalibControl", sizeof( XDeviceAbsCalibControl ) },
	{ "XDeviceResolutionState", sizeof( XDeviceResolutionState ) },
	{ "XDeviceResolutionControl", sizeof( XDeviceResolutionControl ) },
	{ "XDeviceControl", sizeof( XDeviceControl ) },
	{ "XLedFeedbackControl", sizeof( XLedFeedbackControl ) },
	{ "XBellFeedbackControl", sizeof( XBellFeedbackControl ) },
	{ "XIntegerFeedbackControl", sizeof( XIntegerFeedbackControl ) },
	{ "XStringFeedbackControl", sizeof( XStringFeedbackControl ) },
	{ "XKbdFeedbackControl", sizeof( XKbdFeedbackControl ) },
	{ "XPtrFeedbackControl", sizeof( XPtrFeedbackControl ) },
	{ "XFeedbackControl", sizeof( XFeedbackControl ) },
	{ "XLedFeedbackState", sizeof( XLedFeedbackState ) },
	{ "XBellFeedbackState", sizeof( XBellFeedbackState ) },
	{ "XStringFeedbackState", sizeof( XStringFeedbackState ) },
	{ "XIntegerFeedbackState", sizeof( XIntegerFeedbackState ) },
	{ "XPtrFeedbackState", sizeof( XPtrFeedbackState ) },
	{ "XKbdFeedbackState", sizeof( XKbdFeedbackState ) },
	{ "XFeedbackState", sizeof( XFeedbackState ) },
	{ "XDevicePresenceNotifyEvent", sizeof( XDevicePresenceNotifyEvent ) },
	{ "XChangeDeviceNotifyEvent", sizeof( XChangeDeviceNotifyEvent ) },
	{ "XDeviceMappingEvent", sizeof( XDeviceMappingEvent ) },
	{ "XButtonStatus", sizeof( XButtonStatus ) },
	{ "XKeyStatus", sizeof( XKeyStatus ) },
	{ "XValuatorStatus", sizeof( XValuatorStatus ) },
	{ "XDeviceStateNotifyEvent", sizeof( XDeviceStateNotifyEvent ) },
	{ "XInputClass", sizeof( XInputClass ) },
	{ "XProximityNotifyEvent", sizeof( XProximityNotifyEvent ) },
	{ "XDeviceFocusChangeEvent", sizeof( XDeviceFocusChangeEvent ) },
	{ "XDeviceMotionEvent", sizeof( XDeviceMotionEvent ) },
	{ "XDeviceButtonEvent", sizeof( XDeviceButtonEvent ) },
	{ "XDeviceKeyEvent", sizeof( XDeviceKeyEvent ) },
	{ "XIMValuesList", sizeof( XIMValuesList ) },
	{ "XIMHotKeyTriggers", sizeof( XIMHotKeyTriggers ) },
	{ "XIMHotKeyTrigger", sizeof( XIMHotKeyTrigger ) },
	{ "XIMStatusDrawCallbackStruct", sizeof( XIMStatusDrawCallbackStruct ) },
	{ "XIMPreeditCaretCallbackStruct", sizeof( XIMPreeditCaretCallbackStruct ) },
	{ "XIMPreeditDrawCallbackStruct", sizeof( XIMPreeditDrawCallbackStruct ) },
	{ "XIMStringConversionCallbackStruct", sizeof( XIMStringConversionCallbackStruct ) },
	{ "XIMStringConversionText", sizeof( XIMStringConversionText ) },
	{ "XIMPreeditStateNotifyCallbackStruct", sizeof( XIMPreeditStateNotifyCallbackStruct ) },
	{ "XIMText", sizeof( XIMText ) },
	{ "XICCallback", sizeof( XICCallback ) },
	{ "XIMCallback", sizeof( XIMCallback ) },
	{ "XIMStyles", sizeof( XIMStyles ) },
	{ "XOMFontInfo", sizeof( XOMFontInfo ) },
	{ "XOMOrientation", sizeof( XOMOrientation ) },
	{ "XOMCharSetList", sizeof( XOMCharSetList ) },
	{ "XwcTextItem", sizeof( XwcTextItem ) },
	{ "XmbTextItem", sizeof( XmbTextItem ) },
	{ "XFontSetExtents", sizeof( XFontSetExtents ) },
	{ "XEDataObject", sizeof( XEDataObject ) },
	{ "XTextItem16", sizeof( XTextItem16 ) },
	{ "XChar2b", sizeof( XChar2b ) },
	{ "XTextItem", sizeof( XTextItem ) },
	{ "XFontStruct", sizeof( XFontStruct ) },
	{ "XFontProp", sizeof( XFontProp ) },
	{ "XCharStruct", sizeof( XCharStruct ) },
	{ "XEvent", sizeof( XEvent ) },
	{ "XAnyEvent", sizeof( XAnyEvent ) },
	{ "XErrorEvent", sizeof( XErrorEvent ) },
	{ "XMappingEvent", sizeof( XMappingEvent ) },
	{ "XClientMessageEvent", sizeof( XClientMessageEvent ) },
	{ "XColormapEvent", sizeof( XColormapEvent ) },
	{ "XSelectionEvent", sizeof( XSelectionEvent ) },
	{ "XSelectionRequestEvent", sizeof( XSelectionRequestEvent ) },
	{ "XSelectionClearEvent", sizeof( XSelectionClearEvent ) },
	{ "XPropertyEvent", sizeof( XPropertyEvent ) },
	{ "XCirculateRequestEvent", sizeof( XCirculateRequestEvent ) },
	{ "XCirculateEvent", sizeof( XCirculateEvent ) },
	{ "XConfigureRequestEvent", sizeof( XConfigureRequestEvent ) },
	{ "XResizeRequestEvent", sizeof( XResizeRequestEvent ) },
	{ "XGravityEvent", sizeof( XGravityEvent ) },
	{ "XConfigureEvent", sizeof( XConfigureEvent ) },
	{ "XReparentEvent", sizeof( XReparentEvent ) },
	{ "XMapRequestEvent", sizeof( XMapRequestEvent ) },
	{ "XMapEvent", sizeof( XMapEvent ) },
	{ "XUnmapEvent", sizeof( XUnmapEvent ) },
	{ "XDestroyWindowEvent", sizeof( XDestroyWindowEvent ) },
	{ "XCreateWindowEvent", sizeof( XCreateWindowEvent ) },
	{ "XVisibilityEvent", sizeof( XVisibilityEvent ) },
	{ "XNoExposeEvent", sizeof( XNoExposeEvent ) },
	{ "XGraphicsExposeEvent", sizeof( XGraphicsExposeEvent ) },
	{ "XExposeEvent", sizeof( XExposeEvent ) },
	{ "XKeymapEvent", sizeof( XKeymapEvent ) },
	{ "XFocusChangeEvent", sizeof( XFocusChangeEvent ) },
	{ "XCrossingEvent", sizeof( XCrossingEvent ) },
	{ "XMotionEvent", sizeof( XMotionEvent ) },
	{ "XButtonEvent", sizeof( XButtonEvent ) },
	{ "XKeyEvent", sizeof( XKeyEvent ) },
	{ "XModifierKeymap", sizeof( XModifierKeymap ) },
	{ "XTimeCoord", sizeof( XTimeCoord ) },
	{ "XKeyboardState", sizeof( XKeyboardState ) },
	{ "XKeyboardControl", sizeof( XKeyboardControl ) },
	{ "XArc", sizeof( XArc ) },
	{ "XRectangle", sizeof( XRectangle ) },
	{ "XPoint", sizeof( XPoint ) },
	{ "XSegment", sizeof( XSegment ) },
	{ "XColor", sizeof( XColor ) },
	{ "XWindowChanges", sizeof( XWindowChanges ) },
	{ "XImage", sizeof( XImage ) },
	{ "XServerInterpretedAddress", sizeof( XServerInterpretedAddress ) },
	{ "XHostAddress", sizeof( XHostAddress ) },
	{ "XWindowAttributes", sizeof( XWindowAttributes ) },
	{ "XSetWindowAttributes", sizeof( XSetWindowAttributes ) },
	{ "ScreenFormat", sizeof( ScreenFormat ) },
	{ "Screen", sizeof( Screen ) },
	{ "Depth", sizeof( Depth ) },
	{ "Visual", sizeof( Visual ) },
	{ "XGCValues", sizeof( XGCValues ) },
	{ "XPixmapFormatValues", sizeof( XPixmapFormatValues ) },
	{ "XExtCodes", sizeof( XExtCodes ) },
	{ "XExtData", sizeof( XExtData ) },
	{ "XConicalGradient", sizeof( XConicalGradient ) },
	{ "XRadialGradient", sizeof( XRadialGradient ) },
	{ "XLinearGradient", sizeof( XLinearGradient ) },
	{ "XTrap", sizeof( XTrap ) },
	{ "XSpanFix", sizeof( XSpanFix ) },
	{ "XAnimCursor", sizeof( XAnimCursor ) },
	{ "XIndexValue", sizeof( XIndexValue ) },
	{ "XFilters", sizeof( XFilters ) },
	{ "XTransform", sizeof( XTransform ) },
	{ "XTrapezoid", sizeof( XTrapezoid ) },
	{ "XCircle", sizeof( XCircle ) },
	{ "XTriangle", sizeof( XTriangle ) },
	{ "XLineFixed", sizeof( XLineFixed ) },
	{ "XPointFixed", sizeof( XPointFixed ) },
	{ "XPointDouble", sizeof( XPointDouble ) },
	{ "XGlyphElt32", sizeof( XGlyphElt32 ) },
	{ "XGlyphElt16", sizeof( XGlyphElt16 ) },
	{ "XGlyphElt8", sizeof( XGlyphElt8 ) },
	{ "XGlyphInfo", sizeof( XGlyphInfo ) },
	{ "XRenderColor", sizeof( XRenderColor ) },
	{ "XRenderPictureAttributes", sizeof( XRenderPictureAttributes ) },
	{ "XRenderPictFormat", sizeof( XRenderPictFormat ) },
	{ "XRenderDirectFormat", sizeof( XRenderDirectFormat ) },
	{ "XStandardColormap", sizeof( XStandardColormap ) },
	{ "XVisualInfo", sizeof( XVisualInfo ) },
	{ "XComposeStatus", sizeof( XComposeStatus ) },
	{ "XClassHint", sizeof( XClassHint ) },
	{ "XIconSize", sizeof( XIconSize ) },
	{ "XTextProperty", sizeof( XTextProperty ) },
	{ "XWMHints", sizeof( XWMHints ) },
	{ "XSizeHints", sizeof( XSizeHints ) },
};

int main( int n, char** args ){
	int i = 0;
	for( i = 0; i < sizeof( size_values )/sizeof( size_values[0] ); i++ ){
		printf( "%s\t%d\n", size_values[i].name, size_values[i].size );
	}
	return 0;
}



